@@ -5,7 +5,8 @@ An Abode alarm Python library.
 import json
 import logging
 import os
-import requests
+
+from requests_toolbelt import sessions
 from requests.exceptions import RequestException
 
 from .automation import AbodeAutomation
@@ -59,7 +60,7 @@ class Abode:
         self._automations = None
 
         # Create a requests session to persist the cookies
-        self._session = requests.session()
+        self._session = sessions.BaseUrlSession(CONST.BASE_URL)
 
         # Create a new cache template
         self._cache = {
@@ -111,8 +112,7 @@ class Abode:
 
         response = self._session.post(CONST.LOGIN_URL, json=login_data)
 
-        if response.status_code != 200:
-            raise AbodeAuthenticationException((response.status_code, response.text))
+        AbodeAuthenticationException.raise_for(response)
 
         response_object = json.loads(response.text)
 
@@ -129,11 +129,7 @@ class Abode:
             self._save_cache()
 
         oauth_response = self._session.get(CONST.OAUTH_TOKEN_URL)
-
-        if oauth_response.status_code != 200:
-            raise AbodeAuthenticationException(
-                (oauth_response.status_code, oauth_response.text)
-            )
+        AbodeAuthenticationException.raise_for(oauth_response)
 
         oauth_response_object = json.loads(oauth_response.text)
 
@@ -146,37 +142,31 @@ class Abode:
 
         _LOGGER.info("Login successful")
 
-        return True
-
     def logout(self):
         """Explicit Abode logout."""
-        if self._token:
-            header_data = {'ABODE-API-KEY': self._token}
+        if not self._token:
+            return
 
-            self._session = requests.session()
-            self._token = None
-            self._panel = None
-            self._user = None
-            self._devices = None
-            self._automations = None
+        header_data = {'ABODE-API-KEY': self._token}
 
-            try:
-                response = self._session.post(CONST.LOGOUT_URL, headers=header_data)
-                response_object = json.loads(response.text)
-            except OSError as exc:
-                _LOGGER.warning("Caught exception during logout: %s", str(exc))
-                return False
+        self._session = sessions.BaseUrlSession(CONST.BASE_URL)
+        self._token = None
+        self._panel = None
+        self._user = None
+        self._devices = None
+        self._automations = None
 
-            if response.status_code != 200:
-                raise AbodeAuthenticationException(
-                    (response.status_code, response_object['message'])
-                )
+        try:
+            response = self._session.post(CONST.LOGOUT_URL, headers=header_data)
+        except OSError as exc:
+            _LOGGER.warning("Caught exception during logout: %s", exc)
+            return
 
-            _LOGGER.debug("Logout Response: %s", response.text)
+        AbodeAuthenticationException.raise_for(response)
 
-            _LOGGER.info("Logout successful")
+        _LOGGER.debug("Logout Response: %s", response.text)
 
-        return True
+        _LOGGER.info("Logout successful")
 
     def refresh(self):
         """Do a full refresh of all devices and automations."""
@@ -321,19 +311,19 @@ class Abode:
             raise AbodeException(ERROR.INVALID_SETTING, CONST.ALL_SETTINGS)
 
         if setting in CONST.PANEL_SETTINGS:
-            url = CONST.SETTINGS_URL
+            path = CONST.SETTINGS_URL
             data = self._panel_settings(setting, value, validate_value)
         elif setting in CONST.AREA_SETTINGS:
-            url = CONST.AREAS_URL
+            path = CONST.AREAS_URL
             data = self._area_settings(area, setting, value, validate_value)
         elif setting in CONST.SOUND_SETTINGS:
-            url = CONST.SOUNDS_URL
+            path = CONST.SOUNDS_URL
             data = self._sound_settings(area, setting, value, validate_value)
         elif setting in CONST.SIREN_SETTINGS:
-            url = CONST.SIREN_URL
+            path = CONST.SIREN_URL
             data = self._siren_settings(setting, value, validate_value)
 
-        return self.send_request(method="put", url=url, data=data)
+        return self.send_request(method="put", path=path, data=data)
 
     @staticmethod
     def _panel_settings(setting, value, validate_value):
@@ -415,7 +405,7 @@ class Abode:
 
         return {'action': setting, 'option': value}
 
-    def send_request(self, method, url, headers=None, data=None, is_retry=False):
+    def send_request(self, method, path, headers=None, data=None, is_retry=False):
         """Send requests to Abode."""
         if not self._token:
             self.login()
@@ -427,7 +417,7 @@ class Abode:
         headers['ABODE-API-KEY'] = self._token
 
         try:
-            response = getattr(self._session, method)(url, headers=headers, json=data)
+            response = getattr(self._session, method)(path, headers=headers, json=data)
 
             if response and response.status_code < 400:
                 return response
@@ -439,7 +429,7 @@ class Abode:
             # attempt.
             self._token = None
 
-            return self.send_request(method, url, headers, data, True)
+            return self.send_request(method, path, headers, data, True)
 
         raise AbodeException((ERROR.REQUEST))
 
@@ -493,12 +483,9 @@ def _new_sensor(device_json, abode):
 
     version = device_json.get('version', '')
 
-    # this.version.startsWith('MINIPIR') == true ? 'Occupancy Sensor'
-    # : 'Motion Sensor';
-    if version and version.lower().startswith('minipir'):
-        device_json['generic_type'] = CONST.TYPE_OCCUPANCY
-    else:
-        device_json['generic_type'] = CONST.TYPE_MOTION
+    device_json['generic_type'] = (
+        CONST.TYPE_OCCUPANCY if version.startswith('MINIPIR') else CONST.TYPE_MOTION
+    )
 
     return AbodeBinarySensor(device_json, abode)
 
