@@ -1,11 +1,9 @@
 """Test the Abode device classes."""
 import json
-import unittest
-
-import requests_mock
 
 import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
+import pytest
 
 import tests.mock as MOCK
 import tests.mock.login as LOGIN
@@ -13,30 +11,16 @@ import tests.mock.oauth_claims as OAUTH_CLAIMS
 import tests.mock.logout as LOGOUT
 import tests.mock.panel as PANEL
 import tests.mock.automation as AUTOMATION
-import pytest
 
 
-USERNAME = 'foobar'
-PASSWORD = 'deadbeef'
 AID_1 = '47fae27488f74f55b964a81a066c3a01'
 AID_2 = '47fae27488f74f55b964a81a066c3a02'
 AID_3 = '47fae27488f74f55b964a81a066c3a03'
 
 
-@requests_mock.Mocker()
-class TestDevice(unittest.TestCase):
+class TestDevice:
     """Test the generic AbodePy device class."""
 
-    def setUp(self):
-        """Set up Abode module."""
-        self.abode = jaraco.abode.Abode(
-            username=USERNAME, password=PASSWORD, disable_cache=True
-        )
-
-    def tearDown(self):
-        """Clean up after test."""
-        self.abode = None
-
     def tests_automation_init(self, m):
         """Check the Abode automation class init's properly."""
         # Set up URLs
@@ -101,9 +85,7 @@ class TestDevice(unittest.TestCase):
 
         automation_json_changed = json.loads(automation_text_changed)
 
-        automation_id_url = str.replace(
-            CONST.AUTOMATION_ID_URL, '$AUTOMATIONID$', str(automation_json[0]['id'])
-        )
+        automation_id_url = CONST.AUTOMATION_ID_URL.format(id=automation_json[0]['id'])
 
         m.get(automation_id_url, text=automation_text_changed)
 
@@ -322,9 +304,7 @@ class TestDevice(unittest.TestCase):
         assert automation.is_enabled
 
         # Set up our active state change and URL
-        set_active_url = str.replace(
-            CONST.AUTOMATION_ID_URL, '$AUTOMATIONID$', str(automation_json[0]['id'])
-        )
+        set_active_url = CONST.AUTOMATION_ID_URL.format(id=automation_json[0]['id'])
 
         m.patch(
             set_active_url,
@@ -405,9 +385,7 @@ class TestDevice(unittest.TestCase):
         assert automation is not None
 
         # Set up our automation trigger reply
-        set_active_url = str.replace(
-            CONST.AUTOMATION_APPLY_URL, '$AUTOMATIONID$', automation.automation_id
-        )
+        set_active_url = CONST.AUTOMATION_APPLY_URL.format(id=automation.automation_id)
         m.post(set_active_url, text=MOCK.generic_response_ok())
 
         # Test triggering
