@@ -1,9 +1,7 @@
 """Test the Abode binary sensors."""
-import unittest
+import functools
+import itertools
 
-import requests_mock
-
-import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
 
 import tests.mock.login as LOGIN
@@ -19,24 +17,9 @@ import tests.mock.devices.status_display as STATUS_DISPLAY
 import tests.mock.devices.water_sensor as WATER_SENSOR
 
 
-USERNAME = 'foobar'
-PASSWORD = 'deadbeef'
-
-
-class TestBinarySensors(unittest.TestCase):
+class TestBinarySensors:
     """Test the AbodePy binary sensors."""
 
-    def setUp(self):
-        """Set up Abode module."""
-        self.abode = jaraco.abode.Abode(
-            username=USERNAME, password=PASSWORD, disable_cache=True
-        )
-
-    def tearDown(self):
-        """Clean up after test."""
-        self.abode = None
-
-    @requests_mock.mock()
     def tests_binary_sensor_properties(self, m):
         """Tests that binary sensor device properties work as expected."""
         # Set up URL's
@@ -106,10 +89,6 @@ class TestBinarySensors(unittest.TestCase):
 
         # Test our devices
         for device in self.abode.get_devices():
-            # Skip alarm devices
-            if device.type == CONST.DEVICE_ALARM:
-                continue
-
             assert not device.is_on, device.type + " is_on failed"
             assert not device.battery_low, device.type + " battery_low failed"
             assert not device.no_response, device.type + " no_response failed"
@@ -171,11 +150,14 @@ class TestBinarySensors(unittest.TestCase):
         m.get(CONST.DEVICES_URL, text=all_devices)
 
         # Refesh devices and test changes
-        for device in self.abode.get_devices(refresh=True):
-            # Skip alarm devices
-            if device.type_tag == CONST.DEVICE_ALARM:
-                continue
-
+        for device in skip_alarms(self.abode.get_devices(refresh=True)):
             assert device.is_on, device.type + " is_on failed"
             assert device.battery_low, device.type + " battery_low failed"
             assert device.no_response, device.type + " no_response failed"
+
+
+def is_alarm(device):
+    return device.type_tag == CONST.DEVICE_ALARM
+
+
+skip_alarms = functools.partial(itertools.filterfalse, is_alarm)
