@@ -1,38 +1,21 @@
 """Test the Abode device classes."""
-import unittest
-
-import requests_mock
 
 import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
 
+import pytest
+
 import tests.mock.login as LOGIN
 import tests.mock.oauth_claims as OAUTH_CLAIMS
 import tests.mock.logout as LOGOUT
 import tests.mock.panel as PANEL
 import tests.mock.devices as DEVICES
 import tests.mock.devices.dimmer as DIMMER
-import pytest
 
 
-USERNAME = 'foobar'
-PASSWORD = 'deadbeef'
-
-
-class TestDimmer(unittest.TestCase):
+class TestDimmer:
     """Test the AbodePy light device with a dimmer."""
 
-    def setUp(self):
-        """Set up Abode module."""
-        self.abode = jaraco.abode.Abode(
-            username=USERNAME, password=PASSWORD, disable_cache=True
-        )
-
-    def tearDown(self):
-        """Clean up after test."""
-        self.abode = None
-
-    @requests_mock.mock()
     def tests_dimmer_device_properties(self, m):
         """Tests that dimmer light devices properties work as expected."""
         # Set up URL's
@@ -70,7 +53,7 @@ class TestDimmer(unittest.TestCase):
         assert not device.is_on
 
         # Set up our direct device get url
-        device_url = str.replace(CONST.DEVICE_URL, '$DEVID$', DIMMER.DEVICE_ID)
+        device_url = CONST.DEVICE_URL.format(device_id=DIMMER.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -93,7 +76,6 @@ class TestDimmer(unittest.TestCase):
         assert device.no_response
         assert device.is_on
 
-    @requests_mock.mock()
     def tests_dimmer_status_changes(self, m):
         """Tests that dimmer device changes work as expected."""
         # Set up URL's
