@@ -1,38 +1,21 @@
 """Test the Abode device classes."""
-import unittest
-
-import requests_mock
 
 import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
 
+import pytest
+
 import tests.mock.login as LOGIN
 import tests.mock.oauth_claims as OAUTH_CLAIMS
 import tests.mock.logout as LOGOUT
 import tests.mock.panel as PANEL
 import tests.mock.devices as DEVICES
 import tests.mock.devices.door_lock as DOOR_LOCK
-import pytest
 
 
-USERNAME = 'foobar'
-PASSWORD = 'deadbeef'
-
-
-class TestDoorLock(unittest.TestCase):
+class TestDoorLock:
     """Test the generic AbodePy device class."""
 
-    def setUp(self):
-        """Set up Abode module."""
-        self.abode = jaraco.abode.Abode(
-            username=USERNAME, password=PASSWORD, disable_cache=True
-        )
-
-    def tearDown(self):
-        """Clean up after test."""
-        self.abode = None
-
-    @requests_mock.mock()
     def tests_lock_device_properties(self, m):
         """Tests that lock devices properties work as expected."""
         # Set up URL's
@@ -64,7 +47,7 @@ class TestDoorLock(unittest.TestCase):
         assert device.is_locked
 
         # Set up our direct device get url
-        device_url = str.replace(CONST.DEVICE_URL, '$DEVID$', DOOR_LOCK.DEVICE_ID)
+        device_url = CONST.DEVICE_URL.format(device_id=DOOR_LOCK.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -85,7 +68,6 @@ class TestDoorLock(unittest.TestCase):
         assert device.no_response
         assert not device.is_locked
 
-    @requests_mock.mock()
     def tests_lock_device_mode_changes(self, m):
         """Tests that lock device changes work as expected."""
         # Set up URL's
