@@ -1,9 +1,8 @@
 """Test the Abode event controller class."""
 import json
-import unittest
 from unittest.mock import call, Mock
 
-import requests_mock
+import pytest
 
 import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
@@ -17,27 +16,11 @@ import tests.mock.panel as PANEL
 import tests.mock.devices.secure_barrier as COVER
 import tests.mock.devices.door_contact as DOORCONTACT
 import tests.mock.devices.ir_camera as IRCAMERA
-import pytest
 
 
-USERNAME = 'foobar'
-PASSWORD = 'deadbeef'
-
-
-class TestEventController(unittest.TestCase):
+class TestEventController:
     """Test the AbodePy event controller."""
 
-    def setUp(self):
-        """Set up Abode module."""
-        self.abode = jaraco.abode.Abode(
-            username=USERNAME, password=PASSWORD, disable_cache=True
-        )
-
-    def tearDown(self):
-        """Clean up after test."""
-        self.abode = None
-
-    @requests_mock.mock()
     def tests_device_id_registration(self, m):
         """Tests that we can register for device events with a device id."""
         # Set up URL's
@@ -72,7 +55,6 @@ class TestEventController(unittest.TestCase):
         # Register our device id
         assert events.add_device_callback(device.device_id, callback)
 
-    @requests_mock.mock()
     def tests_device_registration(self, m):
         """Tests that we can register for device events with a device."""
         # Set up URL's
@@ -101,13 +83,9 @@ class TestEventController(unittest.TestCase):
         events = self.abode.events
         assert events is not None
 
-        def _our_callback(device):
-            assert device is not None
-
         # Register our device
-        assert events.add_device_callback(device, _our_callback)
+        assert events.add_device_callback(device, lambda device: None)
 
-    @requests_mock.mock()
     def tests_device_all_unregistration(self, m):
         """Tests that we can unregister for all device events."""
         # Set up URL's
@@ -136,16 +114,12 @@ class TestEventController(unittest.TestCase):
         events = self.abode.events
         assert events is not None
 
-        def _our_callback(device):
-            assert device is not None
-
         # Register our device
-        assert events.add_device_callback(device, _our_callback)
+        assert events.add_device_callback(device, lambda device: None)
 
         # Unregister all callbacks
         assert events.remove_all_device_callbacks(device)
 
-    @requests_mock.mock()
     def tests_invalid_device(self, m):
         """Tests that invalid devices are not registered."""
         # Set up URL's
@@ -186,7 +160,6 @@ class TestEventController(unittest.TestCase):
         with pytest.raises(jaraco.abode.AbodeException):
             events.add_device_callback(fake_device, callback)
 
-    @requests_mock.mock()
     def tests_invalid_all_device_unregister(self, m):
         """Tests that invalid devices are not all unregistered."""
         # Set up URL's
@@ -266,7 +239,6 @@ class TestEventController(unittest.TestCase):
         with pytest.raises(jaraco.abode.AbodeException):
             events.add_timeline_callback({"lol": "lol"}, callback)
 
-    @requests_mock.mock()
     def tests_device_callback(self, m):
         """Tests that device updates callback correctly."""
         # Set up URL's
@@ -301,7 +273,7 @@ class TestEventController(unittest.TestCase):
         assert events.add_device_callback(device.device_id, callback)
 
         # Set up device update URL
-        device_url = str.replace(CONST.DEVICE_URL, '$DEVID$', COVER.DEVICE_ID)
+        device_url = CONST.DEVICE_URL.format(device_id=COVER.DEVICE_ID)
         m.get(
             device_url,
             text=COVER.device(
@@ -384,7 +356,6 @@ class TestEventController(unittest.TestCase):
         # Test that an invalid event exits cleanly
         events._on_timeline_update({"invalid": "event"})
 
-    @requests_mock.mock()
     def tests_alarm_callback(self, m):
         """Tests that alarm device updates callback correctly."""
         # Set up URL's
@@ -450,7 +421,6 @@ class TestEventController(unittest.TestCase):
         event_json = json.loads(IRCAMERA.timeline_event())
         events._on_timeline_update(event_json)
 
-    @requests_mock.mock()
     def tests_multi_device_callback(self, m):
         """Tests that multiple device updates callback correctly."""
         # Set up URL's
@@ -494,7 +464,7 @@ class TestEventController(unittest.TestCase):
         assert events.add_device_callback([cover, doorcontact], callback)
 
         # Set up device update URL's
-        cover_url = str.replace(CONST.DEVICE_URL, '$DEVID$', COVER.DEVICE_ID)
+        cover_url = CONST.DEVICE_URL.format(device_id=COVER.DEVICE_ID)
         m.get(
             cover_url,
             text=COVER.device(
@@ -505,7 +475,7 @@ class TestEventController(unittest.TestCase):
             ),
         )
 
-        door_url = str.replace(CONST.DEVICE_URL, '$DEVID$', DOORCONTACT.DEVICE_ID)
+        door_url = CONST.DEVICE_URL.format(device_id=DOORCONTACT.DEVICE_ID)
         m.get(
             door_url,
             text=DOORCONTACT.device(devid=COVER.DEVICE_ID, status=CONST.STATUS_OPEN),
