@@ -1,7 +1,6 @@
 """Test the Abode device classes."""
-import unittest
 
-import requests_mock
+import pytest
 
 import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
@@ -12,27 +11,11 @@ import tests.mock.logout as LOGOUT
 import tests.mock.panel as PANEL
 import tests.mock.devices as DEVICES
 import tests.mock.devices.power_switch_meter as POWERMETER
-import pytest
 
 
-USERNAME = 'foobar'
-PASSWORD = 'deadbeef'
-
-
-class TestPowerSwitchMeter(unittest.TestCase):
+class TestPowerSwitchMeter:
     """Test the AbodePy power switch meter class."""
 
-    def setUp(self):
-        """Set up Abode module."""
-        self.abode = jaraco.abode.Abode(
-            username=USERNAME, password=PASSWORD, disable_cache=True
-        )
-
-    def tearDown(self):
-        """Clean up after test."""
-        self.abode = None
-
-    @requests_mock.mock()
     def tests_switch_device_properties(self, m):
         """Tests that switch devices properties work as expected."""
         # Set up URL's
@@ -64,7 +47,7 @@ class TestPowerSwitchMeter(unittest.TestCase):
         assert not device.is_on
 
         # Set up our direct device get url
-        device_url = str.replace(CONST.DEVICE_URL, '$DEVID$', POWERMETER.DEVICE_ID)
+        device_url = CONST.DEVICE_URL.format(device_id=POWERMETER.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -85,7 +68,6 @@ class TestPowerSwitchMeter(unittest.TestCase):
         assert device.no_response
         assert device.is_on
 
-    @requests_mock.mock()
     def tests_switch_status_changes(self, m):
         """Tests that switch device changes work as expected."""
         # Set up URL's
